// -*- C++ -*-
/***************************************************************************
                             libmenu
                          --------------------
    begin                : Sun May 6 2001
    copyleft             : Giuseppe "denever" Martino
    email                : rdmartin@infinito.it
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
 *                                                                         *
 ***************************************************************************/

#include <string>
#include <vector>

namespace libmenu
{
    typedef unsigned int id_type;
    typedef void (*Function)();

    class Item
    {
    private:
	unsigned int m_id;
	std::string m_caption;
	Function m_cmd;
	
    public:
	Item(id_type id):m_id(id) {};
	Item(const Item& cpy);
	Item(id_type id, std::string c, void(*pf)()): m_id(id), m_caption(c), m_cmd(pf) {};

	std::string caption() const;
	void exe() const;
	Item& operator=(const Item&);
	
	inline id_type id() const
	{
	    return m_id;
	}
    };


    class Menu
    {
    private:
	std::string m_title;
	std::string m_prompt;
	std::vector<Item> m_its;
	bool m_running;
	unsigned int m_last;
		
    public:
	Menu();
	Menu(const std::string&, const std::string&);
	Menu(const Menu& cpy);
	
	void show();
	void add_item(id_type, std::string, Function);
	void operator--();
	void add_item_at(unsigned int, id_type, std::string, Function);
	void delete_item_at(unsigned int);
	void delete_item(id_type);
	bool find(id_type);

	inline void set_title(std::string title)
	{
	    m_title = title;
	}

	inline void set_prompt(std::string prompt)
	{
	    m_prompt = prompt;
	}

	inline bool running()
	{
	    return m_running;
	}
	
	inline void close()
	{
	    m_running = false;
	}
	
	inline unsigned last_selected()
	{
	    return m_last;
	}
    };
}
